import { HttpClient, HttpHeaders } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { switchMap } from 'rxjs';
import { environment } from '../../../environments/environment';
import { Pin } from '../../model/Pin';
import { AutocompleteService } from '../auto-complete/auto-complete.service';
// import { ImageService } from '../image/image.service';

@Injectable({
  providedIn: 'root',
})
export class PinService {
  allPins: Pin[] = [];
  filteredPins: Pin[] = [];

  private apiURL = environment.apiURL;

  constructor(
    private http: HttpClient,
    private autoCompleteService: AutocompleteService // private imageService: ImageService
  ) {}

  getPins(): any {
    const url = `${this.apiURL}/pins`;
    const headers = new HttpHeaders({
      'Content-Type': 'application/json',
      Authorization: 'Bearer ' + localStorage.getItem('auth_token'),
    });
    return this.http.get<any>(url, { headers });
  }

  addPin(pin: Pin) {
    const url = `${this.apiURL}/pin/add`;
    const headers = new HttpHeaders({
      'Content-Type': 'application/json',
      Authorization: 'Bearer ' + localStorage.getItem('auth_token'),
    });
    return this.http.post<any>(
      url, pin, { headers }
    );
  }

  updatePin(
    id: string,
    pin: Pin
  ) {
    const url = `${this.apiURL}/pin/${id}`;
    const headers = new HttpHeaders({
      'Content-Type': 'application/json',
      Authorization: 'Bearer ' + localStorage.getItem('auth_token'),
    });

    // Obtenir les coordonnées GPS à partir de l'adresse
    return this.http.patch<any>(
      url, pin, { headers }
    );
  }

  deletePin(id: string) {
    const url = `${this.apiURL}/pin/${id}`;
    const headers = new HttpHeaders({
      'Content-Type': 'application/json',
      Authorization: 'Bearer ' + localStorage.getItem('auth_token'),
    });
    return this.http.delete<any>(url, { headers });
  }

  sharePin(pinId: string, friendId: string) {
    const url = `${this.apiURL}/pin/${pinId}/share`;
    const headers = new HttpHeaders({
      'Content-Type': 'application/json',
      Authorization: 'Bearer ' + localStorage.getItem('auth_token'),
    });
    return this.http.post<any>(url, { friend_id: friendId }, { headers });
  }
}
